@@ -1,10 +1,8 @@
-"""
-    @Author: Justin C Presley
-    @Author-Email: justincpresley@gmail.com
-    @Project: NDN State Vector Sync Protocol
-    @Source-Code: https://github.com/justincpresley/ndn-python-svs
-    @Pip-Library: https://pypi.org/project/ndn-svs/
-"""
+#    @Author: Justin C Presley
+#    @Author-Email: justincpresley@gmail.com
+#    @Project: NDN State Vector Sync Protocol
+#    @Source-Code: https://github.com/justincpresley/ndn-python-svs
+#    @Pip-Library: https://pypi.org/project/ndn-svs/
 
 # Basic Libraries
 import asyncio as aio
@@ -21,10 +19,16 @@ from ndn.security import Keychain
 from ndn_python_repo import Storage
 # Custom Imports
 from .svs_base import SVSyncBase
-from .svs_core import MissingData, SVSyncCore
+from .core import MissingData, SVSyncCore
+from .security import SecurityOptions
 
+# Class Type: an abstract API thread class
+# Class Purpose:
+#   to push SVS to a separate thread so SVS does not become encounter a block.
+#   to derive different SVSync_Thread classes from.
+#   to allow the user to interact with SVS, fetch and publish.
 class SVSyncBase_Thread(Thread):
-    def __init__(self, groupPrefix:Name, nid:Name, updateCallback:Callable, storage:Optional[Storage]=None, face:Optional[Face]=None, keychain:Optional[Keychain]=None) -> None:
+    def __init__(self, groupPrefix:Name, nid:Name, updateCallback:Callable, storage:Optional[Storage]=None, securityOptions:Optional[SecurityOptions]=None, face:Optional[Face]=None, keychain:Optional[Keychain]=None) -> None:
         logging.info(f'SVSync_Thread: Created thread to push SVS to.')
         Thread.__init__(self)
         self.groupPrefix = groupPrefix
@@ -33,6 +37,7 @@ class SVSyncBase_Thread(Thread):
         self.storage = storage
         self.face = face
         self.keychain = keychain
+        self.secOptions = securityOptions
         self.svs = None
         self.loop = None
         self.app = None
@@ -63,7 +68,7 @@ class SVSyncBase_Thread(Thread):
     def getSVSync(self) -> SVSyncBase:
         return self.svs
     async def fetchData(self, nid:Name, seqNum:int, retries:int=0) -> Optional[bytes]:
-        await self.svs.fetchData(nid, seqNum, retries)
+        return await self.svs.fetchData(nid, seqNum, retries)
     def publishData(self, data:bytes) -> None:
         self.svs.publishData(data)
     def getCore(self) -> SVSyncCore:
